@@ -181,8 +181,6 @@ gdImagePtr gdImageCreateTrueColor(int sx, int sy);
 	return a palette or truecolor image based on the
 	nature of the file being loaded. Truecolor PNG
 	stays truecolor; palette PNG stays palette-based;
-gdImagePtr gdImageCreateFromGif(FILE *fd);
-gdImagePtr gdImageCreateFromGifCtx(gdIOCtxPtr in);
 	JPEG is always truecolor. */
 gdImagePtr gdImageCreateFromPng(FILE *fd);
 gdImagePtr gdImageCreateFromPngCtx(gdIOCtxPtr in);
@@ -203,6 +201,10 @@ typedef struct {
 
 gdImagePtr gdImageCreateFromPngSource(gdSourcePtr in);
 
+gdImagePtr gdImageCreateFromGif(FILE *fd);
+gdImagePtr gdImageCreateFromGifCtx(gdIOCtxPtr in);
+gdImagePtr gdImageCreateFromGifSource(gdSourcePtr in);
+
 gdImagePtr gdImageCreateFromGd(FILE *in);
 gdImagePtr gdImageCreateFromGdCtx(gdIOCtxPtr in);
 
@@ -253,12 +255,26 @@ char *gdImageStringTTF(gdImage *im, int *brect, int fg, char *fontlist,
 char *gdImageStringFT(gdImage *im, int *brect, int fg, char *fontlist,
                 double ptsize, double angle, int x, int y, char *string);
 
+typedef struct {
+	int flags; /* for future expansion logical OR of gdFTEX_ values */
+	double linespacing; /* fine tune line spacing for '\n' */
+} gdFTStringExtra, *gdFTStringExtraPtr;
+#define gdFTEX_LINESPACE 1
+
+/* FreeType 2 text output with fine tuning */
+char *
+gdImageStringFTEx(gdImage * im, int *brect, int fg, char * fontlist,
+		double ptsize, double angle, int x, int y, char * string,
+		gdFTStringExtraPtr strex);
+
+
 /* Point type for use in polygon drawing. */
 typedef struct {
 	int x, y;
 } gdPoint, *gdPointPtr;
 
 void gdImagePolygon(gdImagePtr im, gdPointPtr p, int n, int c);
+void gdImageOpenPolygon(gdImagePtr im, gdPointPtr p, int n, int c);
 void gdImageFilledPolygon(gdImagePtr im, gdPointPtr p, int n, int c);
 
 /* These functions still work with truecolor images, 
@@ -349,6 +365,14 @@ void gdImageJpegCtx(gdImagePtr im, gdIOCtx *out, int quality);
 /* Best to free this memory with gdFree(), not free() */
 void *gdImageJpegPtr(gdImagePtr im, int *size, int quality);
 
+void gdImageLzw(gdImagePtr im, FILE *out);
+void* gdImageLzwPtr(gdImagePtr im, int *size);
+void gdImageLzwCtx(gdImagePtr im, gdIOCtxPtr out);
+
+void gdImageBigGif(gdImagePtr im, FILE *out);
+void* gdImageBigGifPtr(gdImagePtr im, int *size);
+void gdImageBigGifCtx(gdImagePtr im, gdIOCtxPtr out);
+
 /* A custom data sink. For backwards compatibility. Use
 	gdIOCtx instead. */
 /* The sink function must return -1 on error, otherwise the number
@@ -361,6 +385,11 @@ typedef struct {
 
 void gdImagePngToSink(gdImagePtr im, gdSinkPtr out);
 
+void gdImageGif(gdImagePtr im, FILE *out);
+void* gdImageGifPtr(gdImagePtr im, int *size);
+void gdImageGifCtx(gdImagePtr im, gdIOCtxPtr out);
+void gdImageGifToSink(gdImagePtr im, gdSinkPtr out);
+
 void gdImageGd(gdImagePtr im, FILE *out);
 void gdImageGd2(gdImagePtr im, FILE *out, int cs, int fmt);
 
